@@ -11,14 +11,15 @@ License: See LICENSE file.
 
 """
 
-import distutils.version
 import importlib
 
+from packaging.version import Version
+
 # update this when changing setup.py
 VERSIONS = {
     "tabview": "1.4",
     "pandas": "0.24.1",
-    "cchardet": "2.1.7",
+    "faust-cchardet": "2.1.14",
     "wilderness": "0.1.5",
 }
 
@@ -69,7 +70,7 @@ def import_optional_dependency(name, raise_on_missing=True):
     version = getattr(module, "__version__", None)
     if version is None:
         return
-    if distutils.version.LooseVersion(version) < min_version:
+    if Version(version) < Version(min_version):
         msg = (
             f"CleverCSV requires version '{min_version}' or newer for "
             "optional dependency '{name}'. Please update the package "
